==> sc4ui5radiobutton-1.0.1.tgz: package/index.js <==
import {html, css,LitElement} from 'lit';
import "@ui5/webcomponents/dist/RadioButton";
import "@ui5/webcomponents/dist/features/InputElementsFormSupport.js";

import {sequenceGenerator} from "sc4datarequest"

export class WCRadioButton extends LitElement {
  static get styles() {
    return css``;
  }

  static get properties() {
    return {
      texts: {
        type: String,
        hasChanged(newVal, oldVal) {
          return true;
        }
      },
      values: {
        type:String,
        hasChanged(newVal, oldVal) {
          return true;
        }
      },
      value:{
        type:String,
        hasChanged(newVal, oldVal) {
          return true;
        }
      }
    }
  }

  updated(){
    let names=this.texts.split(";");
    let values=this.values.split(";");
    let count=names.length<values.length?names.length:values.length;
    let htmls=[];
    let selectIndex=0
    for(let i=0;i<count;i++){
      if(values[i]==this.value){
        selectIndex=i;
        break;
      }
    }
    let name="ui5-rb-" + sequenceGenerator.getNext("radiobutton");
    for(let i=0;i<count;i++){
        htmls.push(`<ui5-radiobutton name="${name}" text="${names[i]}" value="${values[i]}" ${i==selectIndex?"selected":""}></ui5-radiobutton>`);
    }
    this.shadowRoot.getElementById("container").innerHTML=htmls.join("");
    this.shadowRoot.querySelectorAll("ui5-radiobutton").forEach((radionbutton)=>{
      radionbutton.addEventListener("select",(item)=>{
        this.value=item.target.getAttribute("value");
      });
    });
  }


  constructor() {
    super();
  }

  firstUpdated(changedProperties) {
    
  }

  render() {
    return html`
      <div id="container">
      </div>`;
  }
}

customElements.define('li-radiobutton', WCRadioButton);

==> sc4ui5radiobutton-1.0.2.tgz: package/index.js <==
import {html, css,LitElement} from 'lit';
import "@ui5/webcomponents/dist/RadioButton";
import "@ui5/webcomponents/dist/features/InputElementsFormSupport.js";

import {sequenceGenerator} from "sc4datarequest"

export class WCRadioButton extends LitElement {
  static get styles() {
    return css``;
  }

  static get properties() {
    return {
      texts: {
        type: String,
        hasChanged(newVal, oldVal) {
          return true;
        }
      },
      values: {
        type:String,
        hasChanged(newVal, oldVal) {
          return true;
        }
      },
      value:{
        type:String,
        hasChanged(newVal, oldVal) {
          return true;
        }
      }
    }
  }

  updated(){
    let names=this.texts?this.texts.split(";"):[];
    let values=this.values?this.values.split(";"):[];
    let count=names.length<values.length?names.length:values.length;
    let htmls=[];
    let selectIndex=0
    for(let i=0;i<count;i++){
      if(values[i]==this.value){
        selectIndex=i;
        break;
      }
    }
    let name="ui5-rb-" + sequenceGenerator.getNext("radiobutton");
    for(let i=0;i<count;i++){
        htmls.push(`<ui5-radiobutton name="${name}" text="${names[i]}" value="${values[i]}" ${i==selectIndex?"selected":""}></ui5-radiobutton>`);
    }
    this.shadowRoot.getElementById("container").innerHTML=htmls.join("");
    this.shadowRoot.querySelectorAll("ui5-radiobutton").forEach((radionbutton)=>{
      radionbutton.addEventListener("select",(item)=>{
        this.value=item.target.getAttribute("value");
      });
    });
  }


  constructor() {
    super();
  }

  firstUpdated(changedProperties) {
    
  }

  render() {
    return html`
      <div id="container">
      </div>`;
  }
}

customElements.define('li-radiobutton', WCRadioButton);
